alignerconfig – BRDR - Aligning borders

# AlignerConfig

    configs.AlignerConfig(
        correction_distance=0.01,
        diff_metric=DiffMetric.SYMMETRICAL_AREA_CHANGE,
        mitre_limit=10,
        max_workers=None,
        log_metadata=True,
        add_observations=True,
    )

Configuration for the alignment and correction of spatial boundaries.

## Parameters

Name | Type | Description | Default
--- | --- | --- | ---
correction_distance | float | The maximum distance allowed for moving vertices during the alignment/correction phase. | `0.01`
diff_metric | DiffMetric | The metric used to calculate the difference or distance between the input geometry and the reference. | `DiffMetric.SYMMETRICAL_AREA_CHANGE`
mitre_limit | float | The miter ratio limit for buffering. Controls the maximum length of join corners to prevent spikes in sharp angles. Corners exceeding this ratio are beveled. | `10`
max_workers | int | The maximum number of parallel worker threads/processes to use. If None, the system determines the optimal count. | `None`
log_metadata | bool | If True, detailed metadata about the alignment process will be recorded in the logs. | `True`